# LunesPy

**The [old version](https://github.com/Lunes-platform/LunesPy/tree/old) is being discontinued, but it can still be used at your own risk and risk.**

Library for communication with nodes in mainnet or testnet of the lunes-blockchain network
Allows the automation of **sending assets**, **issue end reissue tokens**, **lease**, **registry**, and **create new wallet**.
<!-- 
## Prerequisites

Before you begin, ensure you have met the following requirements:
* You have installed the latest version of `python`

## Installing LunesPy

To use LunesPy, follow these steps:

Linux and macOS:
```
<install_command>
```

Windows:
```
<install_command>
``` -->
## What's new
Look at the changes [here](./CHANGELOG.md)


## Using LunesPy

To use LunesPy, follow these [tutorial](./TUTORIAL.md)

## Contributing to LunesPy

To contribute to LunesPy, follow these [step](./docs/CONTRIBUTING.md)

## Contributors

Thanks to the following people who have contributed to this project:

* [@olivmath](https://github.com/olivmath)
* [@marcoslkz](https://github.com/marcoslkz)
* [@VanJustin](https://github.com/VanJustin)

<!---
You might want to consider using something like the [All Contributors](https://github.com/all-contributors/all-contributors) specification and its [emoji key](https://allcontributors.org/docs/en/emoji-key).
--->
## Contact

If you want to contact me you can reach me at <lucas.oliveira@lunes.io>.

## License
<!--- If you're not sure which open license to use see https://choosealicense.com/--->

This project uses the following license: [Apache License Version 2.0, January 2004](./LICENSE).
